@@ -104,6 +104,7 @@ void scr_process_key(keycode kcode);
 void scr_init_bindings(void);
 void scr_init_locale_charset(void);
 void scr_init_curses(void);
+void scr_init_settings(void);
 void scr_terminate_curses(void);
 gboolean scr_curses_status(void);
 void scr_draw_main_window(unsigned int fullinit);
@@ -147,6 +148,7 @@ void scr_roster_jump_jid(char *);
 void scr_roster_jump_alternate(void);
 void scr_roster_unread_message(int);
 void scr_roster_display(const char *);
+void scr_roster_next_open_buffer(void);
 
 void scr_buffer_top_bottom(int topbottom);
 void scr_buffer_clear(void);
@@ -177,10 +179,10 @@ void readline_updowncase_word(int);
 void readline_capitalize_word(void);
 void readline_backward_char(void);
 void readline_forward_char(void);
-int  readline_accept_line(int down_history);
+void readline_accept_line(int down_history);
 void readline_clear_history(void);
 void readline_cancel_completion(void);
-void readline_do_completion(void);
+void readline_do_completion(gboolean fwd);
 void readline_refresh_screen(void);
 void readline_disable_chat_mode(guint show_roster);
 void readline_hist_beginning_search_bwd(void);
